@@ -19,6 +19,7 @@
 
 #include <libbonobo.h>
 #include <libgnomeui/gnome-icon-lookup.h>
+#include <libgnomevfs/gnome-vfs-utils.h>
 #include <libgnomevfs/gnome-vfs-uri.h>
 #include <libgnomevfs/gnome-vfs-ops.h>
 #include <libgnomevfs/gnome-vfs-mime-handlers.h>
@@ -513,17 +514,24 @@ drop_uri (PanelWidget *panel,
 	  const char  *icon)
 {
 	char  *base;
+	char  *name;
+	char  *comment;
 
 	if (!panel_profile_id_lists_are_writable ())
 		return FALSE;
 
 	base = g_path_get_basename (uri);
-
-	panel_launcher_create_from_info (
-		panel->toplevel, position, FALSE, uri, base, uri, icon);
-
+	name = gnome_vfs_unescape_string_for_display (base);
 	g_free (base);
 
+	comment = gnome_vfs_unescape_string_for_display (uri);
+
+	panel_launcher_create_from_info (panel->toplevel, position, FALSE,
+					 uri, name, comment, icon);
+
+	g_free (name);
+	g_free (comment);
+
 	return TRUE;
 }
 
